import com.google.gson.stream.JsonWriter;

import java.io.File;
import java.io.FileWriter;
import java.io.IOException;
import java.util.ArrayList;
import java.util.List;

public class Main {
    public static final int MOCK_SIZE = 3;

    public static void main(String[] args) throws IOException {
        List<User> users = getMockUsers(MOCK_SIZE);

        File file = new File("src/main/resources/users.json");
        // Создаем врайтер
        JsonWriter writer = new JsonWriter(new FileWriter(file));
        // говорим, что оступ будет два пробела относительно родителя
        writer.setIndent("  ");
        // пишем в файл данные
        writeUsers(writer, users);
        // обязательно закрываем врайтер
        writer.close();
    }

    /**
     * Функция-генератор списка пользователей
     *
     * @param count Количество пользователей
     * @return Список пользователей
     */
    private static List<User> getMockUsers(int count) {
        List<User> users = new ArrayList<User>();
        for (int i = 0; i < count; i++) {
            int id = i + 1;
            String firstName = "first_name_" + id;
            String lastName = "last_name_" + id;
            User user = new User(id, firstName, lastName);
            users.add(user);
        }
        return users;
    }

    /**
     * Пишет список в json файл
     *
     * @param writer врайтер
     * @param users  Список пользователей
     */
    private static void writeUsers(JsonWriter writer, List<User> users) throws IOException {
        writer.beginArray();
        for (User user : users) {
            writeUser(writer, user);
        }
        writer.endArray();
    }

    /**
     * Пишет информацию об одном пользователе в json файл
     *
     * @param writer врайтер
     * @param user   Пользователь
     */
    private static void writeUser(JsonWriter writer, User user) throws IOException {
        writer.beginObject();
        writer.name("id").value(user.getId());
        writer.name("first_name").value(user.getFirstName());
        writer.name("last_name").value(user.getLastName());
        writer.endObject();
    }
}
